A character vector of all accepted values for the sample_type column
in metadata_sample files. Used by check_metadata_samples,
check_metadata_samples_lab, and check_metadata_samples_olink.
A character vector of all accepted values for the sample_type column
in metadata_sample files. Used by check_metadata_samples,
check_metadata_samples_lab, and check_metadata_samples_olink.