The release folder structure is
PHASE/OMICS/TCODE_NAME/ASSAY/, where the PHASE folder is the phase
details with two exceptions:
pass1c-06releases are written to thepass1a-06folderEvery
HUMAN-MAINrelease is written to thehuman-mainfolder, no matter how many tranches are combined, and whetherHUMAN-PRECOVIDis combined with them. For example,human-main-tr01,human-main-tr01-tr02-tr03, andhuman-precovid-main-tr01-tr02are all written tohuman-main
The full phase details (including every tranche) is still used for the file names, so the content of the release folder identifies the combined phases.