A group might choose to combine different phases, due to
the complications associated with PASS1A/1C, or to release several human
tranches together. If they choose to combine phases, the CAS must provide a
new file metadata_phase.txt with a single line, as for example:
PASS1A-06|PASS1C-06 or HUMAN-MAIN-TR01|HUMAN-MAIN-TR02. Human and animal
phases cannot be combined. This function checks if the
file is available, and set that phase as the phases to validate. In summary,
the order of preference is:
function's argument: dmaqc_phase2validate (if provided in the validation functions)
metadata_phase.txtfile if available in the batch folder.Phase in folder structure